@@ -25,4 +25,6 @@ def main():
     except KeyError:
         print("The API expects City State passed as arguments.  Example: Pasadena California (note: CA will not work)")
     except:
-        print("Whoops, I'm not sure what happened here.  Good luck!")
\ No newline at end of file
+        print("Whoops, I'm not sure what happened here.  Good luck!")
+if __name__ == '__main__':
+    main()
\ No newline at end of file
